@@ -1,3 +1,4 @@
+package Prima::Drawable::Basic; # for metacpan
 package Prima::Drawable;
 
 use strict;
@@ -359,6 +360,6 @@ Prima::Drawable::Basic
 
 =head1 NAME
 
-Basic drawing routings for Prima::Drawable
+Basic drawing routines for Prima::Drawable
 
 =cut
